*************************
Astropop Documentation
*************************

.. warning::
    Documentation outdated. Do not use it. We are rewriting it!

.. TODO:: Insert detailed install instructions here

***************
For Users
***************

The users documentation, focused on the modules technical details, API usage and examples can be found in our user guide:

.. toctree::
    :maxdepth: 1

    user_guide.rst

For end users that just want to reduce their data using ASTROPOP, you can follow our reduction examples on this documentations:

.. toctree::
    :maxdepth: 1

    ipynb/diy_reduction_script.ipynb


***************
Developer Docs
***************

.. toctree::
    :maxdepth: 1

    dev/pixel_convention

***************
API
***************

* :ref:`modindex`
